==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QMessageAuthenticationCode_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qmessageauthenticationcode.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcryptographichash.h>
#include <QtCore/qiodevice.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QMessageAuthenticationCode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMessageAuthenticationCode")
    QMessageAuthenticationCode *_ptr = reinterpret_cast<QMessageAuthenticationCode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArray)
void __qt_construct_QMessageAuthenticationCode_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArray)")
    jobject method0 = __java_arguments[0].l;
    QCryptographicHash::Algorithm __qt_method0 = qtjambi_cast<QCryptographicHash::Algorithm>(__jni_env, method0);
    QMessageAuthenticationCode *__qt_this = new(__qtjambi_ptr) QMessageAuthenticationCode(QCryptographicHash::Algorithm(__qt_method0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArray)
void __qt_construct_QMessageAuthenticationCode_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArray)")
    jobject method0 = __java_arguments[0].l;
    QCryptographicHash::Algorithm __qt_method0 = qtjambi_cast<QCryptographicHash::Algorithm>(__jni_env, method0);
    jobject key1 = __java_arguments[1].l;
    const QByteArray& __qt_key1 = qtjambi_cast<const QByteArray& >(__jni_env, key1);
    QMessageAuthenticationCode *__qt_this = new(__qtjambi_ptr) QMessageAuthenticationCode(QCryptographicHash::Algorithm(__qt_method0), __qt_key1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QMessageAuthenticationCode
void __qt_destruct_QMessageAuthenticationCode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMessageAuthenticationCode")
    reinterpret_cast<QMessageAuthenticationCode*>(ptr)->~QMessageAuthenticationCode();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMessageAuthenticationCode::QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_initialize_1native__Lio_qt_core_QMessageAuthenticationCode_2Lio_qt_core_QCryptographicHash_00024Algorithm_2Lio_qt_core_QByteArray_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject method0,
 jobject key1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMessageAuthenticationCode::QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArray)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = method0;
        arguments[1].l = key1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMessageAuthenticationCode_1, sizeof(QMessageAuthenticationCode), typeid(QMessageAuthenticationCode), false, &deleter_QMessageAuthenticationCode, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::addData(QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_addData_1native_1cref_1QByteArray__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::addData(QByteArray)", __qt_this)
        const QByteArray& __qt_data0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(data0);
        __qt_this->addData(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::addData(QIODevice*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_addData_1native_1QIODevice_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID device0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::addData(QIODevice*)", __qt_this)
        QIODevice* __qt_device0 = QtJambiAPI::objectFromNativeId<QIODevice>(device0);
        __java_return_value = __qt_this->addData(__qt_device0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMessageAuthenticationCode::addData(const char*,qsizetype)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_addData_1native_1const_1char_1ptr_1qsizetype__JLjava_nio_ByteBuffer_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::addData(const char*,qsizetype)", __qt_this)
        qsizetype length1{0};
        JBufferConstData __qt_data0_buffer(__jni_env, data0);
        const char* __qt_data0 = __qt_data0_buffer.data<char>();
        length1 = __qt_data0_buffer.size<char>();
        __qt_this->addData(__qt_data0, static_cast<qsizetype>(length1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::reset()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_reset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::reset()", __qt_this)
        __qt_this->reset();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::result()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_result_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::result()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->result();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMessageAuthenticationCode::setKey(QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_setKey_1native_1cref_1QByteArray__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID key0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::setKey(QByteArray)", __qt_this)
        const QByteArray& __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(key0);
        __qt_this->setKey(__qt_key0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::hash(QByteArray,QByteArray,QCryptographicHash::Algorithm)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_hash_1native_1cref_1QByteArray_1cref_1QByteArray_1QCryptographicHash_1Algorithm__JJI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID message0,
 QtJambiNativeID key1,
 jint method2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMessageAuthenticationCode::hash(QByteArray,QByteArray,QCryptographicHash::Algorithm)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QByteArray& __qt_message0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(message0);
        const QByteArray& __qt_key1 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(key1);
        QCryptographicHash::Algorithm __qt_method2 = qtjambi_cast<QCryptographicHash::Algorithm>(__jni_env, method2);
        QByteArray __qt_return_value = QMessageAuthenticationCode::hash(__qt_message0, __qt_key1, QCryptographicHash::Algorithm(__qt_method2));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMessageAuthenticationCode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMessageAuthenticationCode>("QMessageAuthenticationCode", "io/qt/core/QMessageAuthenticationCode");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QMessageAuthenticationCode, {
        ConstructorInfo(&__qt_construct_QMessageAuthenticationCode_0, "Lio/qt/core/QCryptographicHash$Algorithm;")
       ,ConstructorInfo(&__qt_construct_QMessageAuthenticationCode_1, "Lio/qt/core/QCryptographicHash$Algorithm;Lio/qt/core/QByteArray;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMessageAuthenticationCode);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QMessageAuthenticationCode_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qmessageauthenticationcode.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qbytearrayview.h>
#include <QtCore/qcryptographichash.h>
#include <QtCore/qiodevice.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QMessageAuthenticationCode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMessageAuthenticationCode")
    QMessageAuthenticationCode *_ptr = reinterpret_cast<QMessageAuthenticationCode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView)
void __qt_construct_QMessageAuthenticationCode_QCryptographicHash_Algorithm(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView)")
    jobject method0 = __java_arguments[0].l;
    QCryptographicHash::Algorithm __qt_method0 = qtjambi_cast<QCryptographicHash::Algorithm>(__jni_env, method0);
    QMessageAuthenticationCode *__qt_this = new(__qtjambi_ptr) QMessageAuthenticationCode(QCryptographicHash::Algorithm(__qt_method0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView)
void __qt_construct_QMessageAuthenticationCode_QCryptographicHash_Algorithm_QByteArrayView(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView)")
    jobject method0 = __java_arguments[0].l;
    QCryptographicHash::Algorithm __qt_method0 = qtjambi_cast<QCryptographicHash::Algorithm>(__jni_env, method0);
    jobject key1 = __java_arguments[1].l;
    QByteArrayView __qt_key1 = qtjambi_cast<QByteArrayView >(__jni_env, key1);
    QMessageAuthenticationCode *__qt_this = new(__qtjambi_ptr) QMessageAuthenticationCode(QCryptographicHash::Algorithm(__qt_method0), __qt_key1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QMessageAuthenticationCode::QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_initialize_1native__Lio_qt_core_QMessageAuthenticationCode_2Lio_qt_core_QCryptographicHash_00024Algorithm_2Lio_qt_core_QByteArrayView_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject method0,
 jobject key1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMessageAuthenticationCode::QMessageAuthenticationCode(QCryptographicHash::Algorithm,QByteArrayView)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = method0;
        arguments[1].l = key1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMessageAuthenticationCode_QCryptographicHash_Algorithm_QByteArrayView, sizeof(QMessageAuthenticationCode), typeid(QMessageAuthenticationCode), false, &deleter_QMessageAuthenticationCode, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QMessageAuthenticationCode
void __qt_destruct_QMessageAuthenticationCode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMessageAuthenticationCode")
    reinterpret_cast<QMessageAuthenticationCode*>(ptr)->~QMessageAuthenticationCode();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMessageAuthenticationCode::addData(QByteArrayView)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_addData_1native_1QByteArrayView__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::addData(QByteArrayView)", __qt_this)
        QByteArrayView __qt_data0 = QtJambiAPI::valueReferenceFromNativeId<QByteArrayView>(data0);
        __qt_this->addData(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::addData(QIODevice*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_addData_1native_1QIODevice_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID device0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::addData(QIODevice*)", __qt_this)
        QIODevice* __qt_device0 = QtJambiAPI::objectFromNativeId<QIODevice>(device0);
        __java_return_value = __qt_this->addData(__qt_device0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMessageAuthenticationCode::addData(const char*,qsizetype)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_addData_1native_1const_1char_1ptr_1qsizetype__JLjava_nio_ByteBuffer_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::addData(const char*,qsizetype)", __qt_this)
        qsizetype length1{0};
        JBufferConstData __qt_data0_buffer(__jni_env, data0);
        const char* __qt_data0 = __qt_data0_buffer.data<char>();
        length1 = __qt_data0_buffer.size<char>();
        __qt_this->addData(__qt_data0, static_cast<qsizetype>(length1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::reset()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_reset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::reset()", __qt_this)
        __qt_this->reset();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::result()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_result_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::result()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->result();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMessageAuthenticationCode::resultView()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_resultView_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::resultView()const", __qt_this)
        QByteArrayView __qt_return_value = __qt_this->resultView();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMessageAuthenticationCode::setKey(QByteArrayView)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_setKey_1native_1QByteArrayView__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID key0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::setKey(QByteArrayView)", __qt_this)
        QByteArrayView __qt_key0 = QtJambiAPI::valueReferenceFromNativeId<QByteArrayView>(key0);
        __qt_this->setKey(__qt_key0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::swap(QMessageAuthenticationCode&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_swap_1native_1ref_1QMessageAuthenticationCode__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMessageAuthenticationCode *__qt_this = QtJambiAPI::objectFromNativeId<QMessageAuthenticationCode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMessageAuthenticationCode::swap(QMessageAuthenticationCode&)", __qt_this)
        QMessageAuthenticationCode& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QMessageAuthenticationCode>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMessageAuthenticationCode::hash(QByteArrayView,QByteArrayView,QCryptographicHash::Algorithm)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageAuthenticationCode_hash_1native_1QByteArrayView_1QByteArrayView_1QCryptographicHash_1Algorithm__JJI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID message0,
 QtJambiNativeID key1,
 jint method2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMessageAuthenticationCode::hash(QByteArrayView,QByteArrayView,QCryptographicHash::Algorithm)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QByteArrayView __qt_message0 = QtJambiAPI::valueReferenceFromNativeId<QByteArrayView>(message0);
        QByteArrayView __qt_key1 = QtJambiAPI::valueReferenceFromNativeId<QByteArrayView>(key1);
        QCryptographicHash::Algorithm __qt_method2 = qtjambi_cast<QCryptographicHash::Algorithm>(__jni_env, method2);
        QByteArray __qt_return_value = QMessageAuthenticationCode::hash(__qt_message0, __qt_key1, QCryptographicHash::Algorithm(__qt_method2));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMessageAuthenticationCode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMessageAuthenticationCode>("QMessageAuthenticationCode", "io/qt/core/QMessageAuthenticationCode");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QMessageAuthenticationCode, {
        ConstructorInfo(&__qt_construct_QMessageAuthenticationCode_QCryptographicHash_Algorithm, "Lio/qt/core/QCryptographicHash$Algorithm;")
       ,ConstructorInfo(&__qt_construct_QMessageAuthenticationCode_QCryptographicHash_Algorithm_QByteArrayView, "Lio/qt/core/QCryptographicHash$Algorithm;Lio/qt/core/QByteArrayView;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMessageAuthenticationCode);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
